exceptiontools.ExtraMarkError
=============================

.. inheritance-diagram:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
